73f234a0c0
- Validate that hipGetErrorName returns a non empty string for all error enumerators
- Validate that hipGetErrorString returns a non empty string for all error enumerators
- Negative parameter test for hipGetErrorName and hipGetErrorString
- Validate expected behaviour of hipGetLastError and hipPeekAtLastError
- Multithreaded tests for hipGetLastError and hipPeekAtLastError
- Remove threaded_zig_zag_test.
- Validate error string for invalid error enumerator
- Remove empty lines from HipGetLastErrorThreadedTest and HipPeekAtLastErrorTest.
- Removed unnecessary check in hipGetErrorString negative test.
[ROCm/hip-tests commit: 7cb8d2fe5b]
45 строки
1.8 KiB
C++
45 строки
1.8 KiB
C++
/*
|
|
Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.
|
|
|
|
Permission is hereby granted, free of charge, to any person obtaining a copy
|
|
of this software and associated documentation files (the "Software"), to deal
|
|
in the Software without restriction, including without limitation the rights
|
|
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
|
copies of the Software, and to permit persons to whom the Software is
|
|
furnished to do so, subject to the following conditions:
|
|
|
|
The above copyright notice and this permission notice shall be included in
|
|
all copies or substantial portions of the Software.
|
|
|
|
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
|
|
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
|
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
|
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
|
|
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
|
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
|
THE SOFTWARE.
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
#include <hip/hip_runtime_api.h>
|
|
#include <threaded_zig_zag_test.hh>
|
|
|
|
TEST_CASE("Unit_hipGetLastError_Positive_Basic") {
|
|
HIP_CHECK(hipGetLastError());
|
|
HIP_CHECK_ERROR(hipMalloc(nullptr, 1), hipErrorInvalidValue);
|
|
HIP_CHECK_ERROR(hipGetLastError(), hipErrorInvalidValue);
|
|
HIP_CHECK(hipGetLastError());
|
|
}
|
|
|
|
TEST_CASE("Unit_hipGetLastError_Positive_Threaded") {
|
|
class HipGetLastErrorThreadedTest : public ThreadedZigZagTest<HipGetLastErrorThreadedTest> {
|
|
public:
|
|
void TestPart2() { REQUIRE_THREAD(hipMalloc(nullptr, 1) == hipErrorInvalidValue); }
|
|
void TestPart3() { HIP_CHECK(hipGetLastError()); }
|
|
void TestPart4() { REQUIRE_THREAD(hipGetLastError() == hipErrorInvalidValue); }
|
|
};
|
|
|
|
HipGetLastErrorThreadedTest test;
|
|
test.run();
|
|
}
|